/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface CostBudgetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The month when the budget ends (YYYYMM).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#end_month CostBudget#end_month}
    */
    readonly endMonth: number;
    /**
    * The ID of the budget.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#id CostBudget#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * The cost query used to track against the budget.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#metrics_query CostBudget#metrics_query}
    */
    readonly metricsQuery: string;
    /**
    * The name of the budget.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#name CostBudget#name}
    */
    readonly name: string;
    /**
    * The month when the budget starts (YYYYMM).
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#start_month CostBudget#start_month}
    */
    readonly startMonth: number;
    /**
    * entries block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#entries CostBudget#entries}
    */
    readonly entries?: CostBudgetEntries[] | cdktf.IResolvable;
}
export interface CostBudgetEntriesTagFilters {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#tag_key CostBudget#tag_key}
    */
    readonly tagKey: string;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#tag_value CostBudget#tag_value}
    */
    readonly tagValue: string;
}
export declare function costBudgetEntriesTagFiltersToTerraform(struct?: CostBudgetEntriesTagFilters | cdktf.IResolvable): any;
export declare function costBudgetEntriesTagFiltersToHclTerraform(struct?: CostBudgetEntriesTagFilters | cdktf.IResolvable): any;
export declare class CostBudgetEntriesTagFiltersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CostBudgetEntriesTagFilters | cdktf.IResolvable | undefined;
    set internalValue(value: CostBudgetEntriesTagFilters | cdktf.IResolvable | undefined);
    private _tagKey?;
    get tagKey(): string;
    set tagKey(value: string);
    get tagKeyInput(): string | undefined;
    private _tagValue?;
    get tagValue(): string;
    set tagValue(value: string);
    get tagValueInput(): string | undefined;
}
export declare class CostBudgetEntriesTagFiltersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CostBudgetEntriesTagFilters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CostBudgetEntriesTagFiltersOutputReference;
}
export interface CostBudgetEntries {
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#amount CostBudget#amount}
    */
    readonly amount: number;
    /**
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#month CostBudget#month}
    */
    readonly month: number;
    /**
    * tag_filters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#tag_filters CostBudget#tag_filters}
    */
    readonly tagFilters?: CostBudgetEntriesTagFilters[] | cdktf.IResolvable;
}
export declare function costBudgetEntriesToTerraform(struct?: CostBudgetEntries | cdktf.IResolvable): any;
export declare function costBudgetEntriesToHclTerraform(struct?: CostBudgetEntries | cdktf.IResolvable): any;
export declare class CostBudgetEntriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): CostBudgetEntries | cdktf.IResolvable | undefined;
    set internalValue(value: CostBudgetEntries | cdktf.IResolvable | undefined);
    private _amount?;
    get amount(): number;
    set amount(value: number);
    get amountInput(): number | undefined;
    private _month?;
    get month(): number;
    set month(value: number);
    get monthInput(): number | undefined;
    private _tagFilters;
    get tagFilters(): CostBudgetEntriesTagFiltersList;
    putTagFilters(value: CostBudgetEntriesTagFilters[] | cdktf.IResolvable): void;
    resetTagFilters(): void;
    get tagFiltersInput(): cdktf.IResolvable | CostBudgetEntriesTagFilters[] | undefined;
}
export declare class CostBudgetEntriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: CostBudgetEntries[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): CostBudgetEntriesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget datadog_cost_budget}
*/
export declare class CostBudget extends cdktf.TerraformResource {
    static readonly tfResourceType = "datadog_cost_budget";
    /**
    * Generates CDKTF code for importing a CostBudget resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the CostBudget to import
    * @param importFromId The id of the existing CostBudget that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the CostBudget to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/resources/cost_budget datadog_cost_budget} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options CostBudgetConfig
    */
    constructor(scope: Construct, id: string, config: CostBudgetConfig);
    private _endMonth?;
    get endMonth(): number;
    set endMonth(value: number);
    get endMonthInput(): number | undefined;
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _metricsQuery?;
    get metricsQuery(): string;
    set metricsQuery(value: string);
    get metricsQueryInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _startMonth?;
    get startMonth(): number;
    set startMonth(value: number);
    get startMonthInput(): number | undefined;
    get totalAmount(): number;
    private _entries;
    get entries(): CostBudgetEntriesList;
    putEntries(value: CostBudgetEntries[] | cdktf.IResolvable): void;
    resetEntries(): void;
    get entriesInput(): cdktf.IResolvable | CostBudgetEntries[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
