/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DataDatadogCostBudgetConfig extends cdktf.TerraformMetaArguments {
    /**
    * The ID of the budget.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget#id DataDatadogCostBudget#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id: string;
    /**
    * entries block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget#entries DataDatadogCostBudget#entries}
    */
    readonly entries?: DataDatadogCostBudgetEntries[] | cdktf.IResolvable;
}
export interface DataDatadogCostBudgetEntriesTagFilters {
}
export declare function dataDatadogCostBudgetEntriesTagFiltersToTerraform(struct?: DataDatadogCostBudgetEntriesTagFilters | cdktf.IResolvable): any;
export declare function dataDatadogCostBudgetEntriesTagFiltersToHclTerraform(struct?: DataDatadogCostBudgetEntriesTagFilters | cdktf.IResolvable): any;
export declare class DataDatadogCostBudgetEntriesTagFiltersOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataDatadogCostBudgetEntriesTagFilters | cdktf.IResolvable | undefined;
    set internalValue(value: DataDatadogCostBudgetEntriesTagFilters | cdktf.IResolvable | undefined);
    get tagKey(): string;
    get tagValue(): string;
}
export declare class DataDatadogCostBudgetEntriesTagFiltersList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataDatadogCostBudgetEntriesTagFilters[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataDatadogCostBudgetEntriesTagFiltersOutputReference;
}
export interface DataDatadogCostBudgetEntries {
    /**
    * tag_filters block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget#tag_filters DataDatadogCostBudget#tag_filters}
    */
    readonly tagFilters?: DataDatadogCostBudgetEntriesTagFilters[] | cdktf.IResolvable;
}
export declare function dataDatadogCostBudgetEntriesToTerraform(struct?: DataDatadogCostBudgetEntries | cdktf.IResolvable): any;
export declare function dataDatadogCostBudgetEntriesToHclTerraform(struct?: DataDatadogCostBudgetEntries | cdktf.IResolvable): any;
export declare class DataDatadogCostBudgetEntriesOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DataDatadogCostBudgetEntries | cdktf.IResolvable | undefined;
    set internalValue(value: DataDatadogCostBudgetEntries | cdktf.IResolvable | undefined);
    get amount(): number;
    get month(): number;
    private _tagFilters;
    get tagFilters(): DataDatadogCostBudgetEntriesTagFiltersList;
    putTagFilters(value: DataDatadogCostBudgetEntriesTagFilters[] | cdktf.IResolvable): void;
    resetTagFilters(): void;
    get tagFiltersInput(): cdktf.IResolvable | DataDatadogCostBudgetEntriesTagFilters[] | undefined;
}
export declare class DataDatadogCostBudgetEntriesList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DataDatadogCostBudgetEntries[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DataDatadogCostBudgetEntriesOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget datadog_cost_budget}
*/
export declare class DataDatadogCostBudget extends cdktf.TerraformDataSource {
    static readonly tfResourceType = "datadog_cost_budget";
    /**
    * Generates CDKTF code for importing a DataDatadogCostBudget resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DataDatadogCostBudget to import
    * @param importFromId The id of the existing DataDatadogCostBudget that should be imported. Refer to the {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DataDatadogCostBudget to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/datadog/datadog/3.68.0/docs/data-sources/cost_budget datadog_cost_budget} Data Source
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DataDatadogCostBudgetConfig
    */
    constructor(scope: Construct, id: string, config: DataDatadogCostBudgetConfig);
    get endMonth(): number;
    private _id?;
    get id(): string;
    set id(value: string);
    get idInput(): string | undefined;
    get metricsQuery(): string;
    get name(): string;
    get startMonth(): number;
    get totalAmount(): number;
    private _entries;
    get entries(): DataDatadogCostBudgetEntriesList;
    putEntries(value: DataDatadogCostBudgetEntries[] | cdktf.IResolvable): void;
    resetEntries(): void;
    get entriesInput(): cdktf.IResolvable | DataDatadogCostBudgetEntries[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
